Thread (10 messages) flat view 10 messages, 4 authors, 2014-09-11

Re: [PATCH v10 3/3] regulator: RK808: Remove pdata from the regulator

From: Doug Anderson <hidden>
Date: 2014-09-10 02:49:14
Also in: lkml

Hi,

On Tue, Sep 9, 2014 at 6:18 PM, Chris Zhong [off-list ref] wrote:
Signed-off-by: Chris Zhong <redacted>

Tested-by: Heiko Stuebner <redacted>
---

Changes in v10: None
Despite the "None" above, I see that there are indeed changes between
v9 and v10:
diff --git a/drivers/regulator/rk808-regulator.c
b/drivers/regulator/rk808-regulator.c
index 0d5afc4..d91f2b6 100644
--- a/drivers/regulator/rk808-regulator.c
+++ b/drivers/regulator/rk808-regulator.c
@@ -3,8 +3,8 @@
  *
  * Copyright (c) 2014, Fuzhou Rockchip Electronics Co., Ltd
  *
  * Author: Chris Zhong<zyw-TNX95d0MmH7DzftRWevZcw@public.gmane.org>
  * Author: Zhang Qing<zhanqging-TNX95d0MmH7DzftRWevZcw@public.gmane.org>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU General Public License,
@@ -348,6 +348,6 @@ module_platform_driver(rk808_regulator_driver);

 MODULE_DESCRIPTION("regulator driver for the rk808 series PMICs");
 MODULE_AUTHOR("Chris Zhong<zyw-TNX95d0MmH7DzftRWevZcw@public.gmane.org>");
-MODULE_AUTHOR("Zhang Qing<zhanqging-TNX95d0MmH7DzftRWevZcw@public.gmane.org>");
+MODULE_AUTHOR("Zhang Qing<zhangqing-TNX95d0MmH7DzftRWevZcw@public.gmane.org>");
 MODULE_LICENSE("GPL");
 MODULE_ALIAS("platform:rk808-regulator");
That looks like the change requested by Dmitry for v9 (don't remove
the space) plus a typo fix (flipping g/q).  Interestingly enough the
typo fix shows that "MODULE_AUTHOR" should probably also have had a
space before the "<".


Mark: I think you could just take this (possibly fixing the
MODULE_AUTHOR yourself) to fix the linux-next breakage.  You can also
add:

Reviewed-by: Doug Anderson <redacted>
Tested-by: Doug Anderson <redacted>

-Doug
@@ -3,8 +3,8 @@
  * Copyright (c) 2014, Fuzhou Rockchip Electronics Co., Ltd
  *
- * Author: Chris Zhong<zyw-TNX95d0MmH7DzftRWevZcw@public.gmane.org>
- * Author: Zhang Qing<zhanqging-TNX95d0MmH7DzftRWevZcw@public.gmane.org>
+ * Author: Chris Zhong <zyw-TNX95d0MmH7DzftRWevZcw@public.gmane.org>
+ * Author: Zhang Qing <zhangqing-TNX95d0MmH7DzftRWevZcw@public.gmane.org>
  *
  * This program is free software; you can redistribute it and/or modify it
--
To unsubscribe from this list: send the line "unsubscribe devicetree" in
the body of a message to majordomo-u79uwXL29TY76Z2rM5mHXA@public.gmane.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help